Coverage for /Users/davegaeddert/Developer/dropseed/plain/plain-oauth/plain/oauth/migrations/0003_alter_oauthconnection_access_token_and_more.py: 100%

1# Generated by Plain 4.0.6 on 2022-08-11 19:18

2

3 from plain import models

4 from plain.models import migrations

5

6

7 class Migration(migrations.Migration):

8 dependencies = [

9 ("plainoauth", "0002_alter_oauthconnection_options_and_more"),

10 ]

11

12 operations = [

13 migrations.AlterField(

14 model_name="oauthconnection",

15 name="access_token",

16 field=models.CharField(max_length=300),

17 ),

18 migrations.AlterField(

19 model_name="oauthconnection",

20 name="refresh_token",

21 field=models.CharField(blank=True, max_length=300),

22 ),

23 ]